@@ -28,10 +28,9 @@
 extern "C"
 {
 	//cdda_interface.h in cdparanoia 10.2 has a member called 'private' which the C++ compiler doesn't like
-	#define private _private
-	#include <cdda_interface.h>
+    //we will thus use a generated local copy which renames that member.
+	#include "cdda_interface.hpp"
 	#include <cdda_paranoia.h>
-	#undef private
 	void paranoiaCallback(long, int);
 
 	KDE_EXPORT int kdemain(int argc, char ** argv);
